--[[
*
* Core.lua
* 
*
]]--

local Wipemate = LibStub("AceAddon-3.0"):NewAddon("Wipemate", "AceConsole-3.0")

local L = LibStub("AceLocale-3.0"):GetLocale("Wipemate")

local AceConfig 	= LibStub("AceConfig-3.0")
local AceConfigReg 	= LibStub("AceConfigRegistry-3.0")
local AceConfigDialog 	= LibStub("AceConfigDialog-3.0")
local AceGUI = LibStub("AceGUI-3.0")
local ScrollingTable = LibStub("ScrollingTable");


local cols = {
    {
        ["name"] = L["player"],
        ["width"] = 92,
		["align"] = "CENTER",
        ["color"] = { 
			["r"] = 0.5, 
			["g"] = 0.5, 
			["b"] = 1.0, 
			["a"] = 1.0 
		},
		["defaultsort"] = "dsc",
		["sort"] = "dsc",
		["sortnext"] = 3	
    },
    {
        ["name"] = L["wipes"],
        ["width"] = 50,
        ["align"] = "CENTER",
        ["bgcolor"] = { ["r"] = 1.0, ["g"] = 0.0, ["b"] = 0.0, ["a"] = 0.2 },
    },
    {
        ["name"] = L["kills"],
        ["width"] = 50,
        ["align"] = "CENTER",
        ["bgcolor"] = { ["r"] = 0.0, ["g"] = 0.9, ["b"] = 0.0, ["a"] = 0.5 },
    },
}

local data = {
    { "row1", 12, 4, },
    { "row2", 8, 2, },
	{ "row3", 8, 2, },
}


-- Create a container frame
local mainframe
local optionautotrack = true

function Wipemate:CreateGui()
	
	-- Check if Window is already created
	if not mainframe then 

		mainframe = AceGUI:Create("Window")
		mainframe:SetCallback("OnClose",
			function(widget) 
				AceGUI:Release(widget)
				mainframe = nil
			end
		)
		mainframe:SetTitle("Wipemate Raid Stats")
		mainframe:EnableResize(false)
		mainframe:SetLayout("Flow")
		mainframe:SetWidth(250)
	
		-- Create Checkbox Enable Auto
		local EnableAuto = AceGUI:Create("CheckBox")
		EnableAuto:SetWidth(170)
		EnableAuto:SetLabel("Enable AutoStat")
		--EnableAuto:SetCallback("OnValueChanged", function() print("AutoTracking") end)
		EnableAuto:SetCallback("OnValueChanged", SwitchAutoTracking)
		EnableAuto:SetValue(true)
		EnableAuto:SetType("checkbox")
		
		if optionautotrack == true then
			EnableAuto:SetValue(true)
		else
			EnableAuto:SetValue(false)
		end
		
		-- Add to the container
		mainframe:AddChild(EnableAuto)
	
		-- Create Button Wipe
		local ButtonAddWipe = AceGUI:Create("Button")
		ButtonAddWipe:SetWidth(107)
		ButtonAddWipe:SetText("Wipe")
		ButtonAddWipe:SetCallback("OnClick", function() print("Wipe!") end)
		mainframe:AddChild(ButtonAddWipe)
		
		-- Create Button Wipe
		local ButtonAddKill = AceGUI:Create("Button")
		ButtonAddKill:SetWidth(107)
		ButtonAddKill:SetText("Kill")
		ButtonAddKill:SetCallback("OnClick", function() print("Kill!") end)
		mainframe:AddChild(ButtonAddKill)
	
		-- Create Table and add it to the mainframe
		local st = ScrollingTable:CreateST(cols,nil,30,nil,mainframe.frame)
		-- Move Table 48px down
		st.frame:SetPoint("CENTER",mainframe.frame, "CENTER",0,-48);
		-- Set some Table Options 
		st:EnableSelection(false)
		st:SetData(data,true)
	end
	return mainframe
end

function Wipemate:OnInitialize()
	Wipemate:Print(L["Use /wm to show the Wipemate window."])
	Wipemate:RegisterChatCommand("rl", function() ReloadUI() end)
	Wipemate:RegisterChatCommand("wm", "CreateGui")
	Wipemate:SetupOptions()
end

function Wipemate:OnEnable()
    -- Called when the addon is enabled
	if WipemateDB == nil then
		optionautotrack = true
	end
end

function Wipemate:OnDisable()
    -- Called when the addon is disabled
end

function SwitchAutoTracking()
	if optionautotrack == true then
		optionautotrack = false
		Wipemate:Print("Autotraking OFF")
	else
		optionautotrack = true
		Wipemate:Print("Autotraking ON")
	end
end

--[[
**************************
** CONFIG PANEL
**************************
]]--
local option

function fullOptions()
	if not options then
		options = {
			type = "group",
			name = "Wipemate",
			args = {
				general = {
					order	= 1,
					type	= "group",
					name	= L["Main Options"],
					desc	= L["MAIN_OPTIONS_DESC"],
					args = {
					
					}
				}
			}
		}
	end
	return options
end

function Wipemate:ShowWM()
end

function Wipemate:SetupOptions()
	AceConfigReg:RegisterOptionsTable("Wipemate", fullOptions)
	self.optionsFrame = AceConfigDialog:AddToBlizOptions("Wipemate", nil, nil, "general")

	if LibStub:GetLibrary("LibAboutPanel", true) then
		self.optionsFrame["About"] = LibStub:GetLibrary("LibAboutPanel").new("Wipemate", "Wipemate")
	else
		self:Print("Lib AboutPanel not loaded.")
	end
end

function Wipemate:RegisterModuleOptions(name, optionsTable, displayName)
	modularOptions[name] = optionsTable
	self.optionsFrame[name] = AceConfigDialog:AddToBlizOptions("Wipemate", displayName, "Wipemate", name)
end
